/**@name LIBRARY: unLHCLoggingDBUtils.ctl

@author: Josef Hofer (EN-ICE-SCD)

Creation Date: 04/09/2014

Purpose:
This library contains general functions used by the unLHCLoggingDB component.

Usage:
Library of the unLHCLoggingDB component used only by unLHCLoggingDB.

PVSS manager usage: CTRL, UI

Constraints:
	. PVSS version: 3.11
	. Operating system: Linux.
*/

//@{


/*
Global variable to store authentication information

Structure:
  g_mAuthN["user"] string username
  g_mAuthN["pass"] string password
  g_mAuthN["ok"]   bool authentication ok     */
global mapping g_mAuthN;


/**
* Get authentication information, if no information exists then initialise
*
*
* @return  g_mAuthN  output, authentication information
*/
public mapping unLHCLoggingDBUtils_getAuthentication()
{
    if (!mappingHasKey(g_mAuthN, "user")) {
        unLHCLoggingDBUtils_resetAuthentication();
    }
    return g_mAuthN;
}


/**
* Reset authentication information
*/
public void unLHCLoggingDBUtils_resetAuthentication()
{
    g_mAuthN["user"] = "";
    g_mAuthN["pass"] = "";
    g_mAuthN["ok"] = false;
}


/**
* Open panel so that the user can authenticate
*
* @param user       input, forced username
*/
public bool unLHCLoggingDBUtils_openAuthenticationPanel(string user = "")
{
    dyn_float dfState;
    dyn_string dsUserPass;

    ChildPanelOnCentralModalReturn("objects/unLHCLoggingDB/refUnLHCLoggingDBAuthentication.pnl", 
                                   "Authentication",
                                   makeDynString("$user:" + user),
                                   dfState,
                                   dsUserPass
                                  );

    g_mAuthN["user"] = dsUserPass[1];
    g_mAuthN["pass"] = dsUserPass[2];
    g_mAuthN["ok"] = (dfState[1] == 1);
    return (g_mAuthN["ok"]);
}


/**
* Append multiple lines of text to a report file
*
* @param dsLines     input, text
* @param reportFile  input, file
*/
public void unLHCLoggingDBUtils_appendLines(const dyn_string &dsLines, file reportFile)
{
    if (reportFile != 0) {
        int iDsLinesLen = dynlen(dsLines);
        for (int i = 1; i <= iDsLinesLen; i++) {
            fputs(dsLines[i] + "\n", reportFile);
        }
        fflush(reportFile);
    }
}


/**
* Append single line of text to a report file
*
* @param sLine       input, text
* @param reportFile  input, file
*/
public void unLHCLoggingDBUtils_appendLine(const string sLine, file reportFile)
{
    unLHCLoggingDBUtils_appendLines(makeDynString(sLine), reportFile);
}


/**
* Animate ProgressBar and show some percentage
*
* @param iPercent       input, percent 0 ... 100
*/
public void unLHCLoggingDBUtils_animateProgressBar(int iPercent)
{
    if (isFunctionDefined("shapeExists")) { // if we call the function from a control script shapeExists is not defined
        if (shapeExists("progressBar")) { // only if there is a shape called progressBar
            progressBar.progress(iPercent);
        }
    }
}


/**
* Obfuscate file path name to data path
*
* @param pathName       input, pathname of the file
*/
public string unLHCLoggingDBUtils_obfuscatePathName (string pathName) { 
  int index = strpos(pathName, "data");    
  string sResult = substr(pathName, 0, index);    
	 sResult = substr(pathName, index, strlen(pathName) - strlen(sResult));	  	
		return sResult;
}


public void unLHCLoggingDBUtils_toggleColumnVisibility(string table, string column)
{
  shape t = getShape(table);
  if(t) {
    t.namedColumnVisibility(column, !t.namedColumnVisibility(column));
  } 
}




//@}
